@@ -1,5 +1,5 @@
 /* GStreamer
- * Copyright (C) <2005> Wim Taymans <wim@fluendo.com>
+ * Copyright (C) <2005> Wim Taymans <wim.taymans@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -32,10 +32,10 @@ GST_DEBUG_CATEGORY_STATIC (rtpamrpay_debug);
 
 /* references:
  *
- * RFC 3267 - Real-Time Transport Protocol (RTP) Payload Format and File 
- *    Storage Format for the Adaptive Multi-Rate (AMR) and Adaptive 
+ * RFC 3267 - Real-Time Transport Protocol (RTP) Payload Format and File
+ *    Storage Format for the Adaptive Multi-Rate (AMR) and Adaptive
  *    Multi-Rate Wideband (AMR-WB) Audio Codecs.
- *    
+ *
  * ETSI TS 126 201 V6.0.0 (2004-12) - Digital cellular telecommunications system (Phase 2+);
  *                 Universal Mobile Telecommunications System (UMTS);
  *                          AMR speech codec, wideband;
@@ -45,10 +45,10 @@ GST_DEBUG_CATEGORY_STATIC (rtpamrpay_debug);
 
 /* elementfactory information */
 static const GstElementDetails gst_rtp_amrpay_details =
-GST_ELEMENT_DETAILS ("RTP packet payloader",
+GST_ELEMENT_DETAILS ("RTP AMR payloader",
     "Codec/Payloader/Network",
     "Payload-encode AMR or AMR-WB audio into RTP packets (RFC 3267)",
-    "Wim Taymans <wim@fluendo.com>");
+    "Wim Taymans <wim.taymans@gmail.com>");
 
 static GstStaticPadTemplate gst_rtp_amr_pay_sink_template =
     GST_STATIC_PAD_TEMPLATE ("sink",
@@ -116,16 +116,10 @@ gst_rtp_amr_pay_base_init (gpointer klass)
 static void
 gst_rtp_amr_pay_class_init (GstRtpAMRPayClass * klass)
 {
-  GObjectClass *gobject_class;
-  GstElementClass *gstelement_class;
   GstBaseRTPPayloadClass *gstbasertppayload_class;
 
-  gobject_class = (GObjectClass *) klass;
-  gstelement_class = (GstElementClass *) klass;
   gstbasertppayload_class = (GstBaseRTPPayloadClass *) klass;
 
-  parent_class = g_type_class_peek_parent (klass);
-
   gstbasertppayload_class->set_caps = gst_rtp_amr_pay_setcaps;
   gstbasertppayload_class->handle_buffer = gst_rtp_amr_pay_handle_buffer;
 
@@ -136,12 +130,14 @@ gst_rtp_amr_pay_class_init (GstRtpAMRPayClass * klass)
 static void
 gst_rtp_amr_pay_init (GstRtpAMRPay * rtpamrpay, GstRtpAMRPayClass * klass)
 {
+  /* needed because of GST_BOILERPLATE */
 }
 
 static gboolean
 gst_rtp_amr_pay_setcaps (GstBaseRTPPayload * basepayload, GstCaps * caps)
 {
   GstRtpAMRPay *rtpamrpay;
+  gboolean res;
   const GstStructure *s;
   const gchar *str;
 
@@ -165,17 +161,17 @@ gst_rtp_amr_pay_setcaps (GstBaseRTPPayload * basepayload, GstCaps * caps)
     gst_basertppayload_set_options (basepayload, "audio", TRUE, "AMR-WB",
         16000);
 
-  gst_basertppayload_set_outcaps (basepayload,
+  res = gst_basertppayload_set_outcaps (basepayload,
       "encoding-params", G_TYPE_STRING, "1", "octet-align", G_TYPE_STRING, "1",
-      /* don't set the defaults 
-       * 
+      /* don't set the defaults
+       *
        * "crc", G_TYPE_STRING, "0",
        * "robust-sorting", G_TYPE_STRING, "0",
-       * "interleaving", G_TYPE_STRING, "0", 
+       * "interleaving", G_TYPE_STRING, "0",
        */
       NULL);
 
-  return TRUE;
+  return res;
 
   /* ERRORS */
 wrong_type:
@@ -191,6 +187,7 @@ static gint nb_frame_size[16] = {
   12, 13, 15, 17, 19, 20, 26, 31,
   5, -1, -1, -1, -1, -1, -1, 0
 };
+
 static gint wb_frame_size[16] = {
   17, 23, 32, 36, 40, 46, 50, 58,
   60, -1, -1, -1, -1, -1, -1, 0
@@ -205,7 +202,7 @@ gst_rtp_amr_pay_handle_buffer (GstBaseRTPPayload * basepayload,
   guint size, payload_len;
   GstBuffer *outbuf;
   guint8 *payload, *data, *payload_amr;
-  GstClockTime timestamp;
+  GstClockTime timestamp, duration;
   guint packet_len, mtu;
   gint i, num_packets, num_nonempty_packets;
   gint amr_len;
@@ -217,6 +214,7 @@ gst_rtp_amr_pay_handle_buffer (GstBaseRTPPayload * basepayload,
   size = GST_BUFFER_SIZE (buffer);
   data = GST_BUFFER_DATA (buffer);
   timestamp = GST_BUFFER_TIMESTAMP (buffer);
+  duration = GST_BUFFER_DURATION (buffer);
 
   /* setup frame size pointer */
   if (rtpamrpay->mode == GST_RTP_AMR_P_MODE_NB)
@@ -226,7 +224,7 @@ gst_rtp_amr_pay_handle_buffer (GstBaseRTPPayload * basepayload,
 
   GST_DEBUG_OBJECT (basepayload, "got %d bytes", size);
 
-  /* FIXME, only 
+  /* FIXME, only
    * octet aligned, no interleaving, single channel, no CRC,
    * no robust-sorting. To fix this you need to implement the downstream
    * negotiation function. */
@@ -265,21 +263,26 @@ gst_rtp_amr_pay_handle_buffer (GstBaseRTPPayload * basepayload,
   /* now alloc output buffer */
   outbuf = gst_rtp_buffer_new_allocate (payload_len, 0, 0);
 
-  /* copy timestamp, or fabricate one */
-  if (timestamp != GST_CLOCK_TIME_NONE)
-    GST_BUFFER_TIMESTAMP (outbuf) = timestamp;
-  else {
-    /* AMR (nb) and AMR-WB both have 20 ms per frame */
-    /* FIXME: when we do more than one AMR frame per packet, fix this */
-    gint count = basepayload->seqnum - basepayload->seqnum_base;
+  /* copy timestamp */
+  GST_BUFFER_TIMESTAMP (outbuf) = timestamp;
 
-    GST_BUFFER_TIMESTAMP (outbuf) = count * 20 * GST_MSECOND;
+  /* FIXME: when we do more than one AMR frame per packet, fix this */
+  if (duration != GST_CLOCK_TIME_NONE)
+    GST_BUFFER_DURATION (outbuf) = duration;
+  else {
+    GST_BUFFER_DURATION (outbuf) = 20 * GST_MSECOND;
+  }
+
+  if (GST_BUFFER_IS_DISCONT (buffer)) {
+    GST_DEBUG_OBJECT (basepayload, "discont, setting marker bit");
+    GST_BUFFER_FLAG_SET (outbuf, GST_BUFFER_FLAG_DISCONT);
+    gst_rtp_buffer_set_marker (outbuf, TRUE);
   }
 
   /* get payload, this is now writable */
   payload = gst_rtp_buffer_get_payload (outbuf);
 
-  /*   0 1 2 3 4 5 6 7 
+  /*   0 1 2 3 4 5 6 7
    *  +-+-+-+-+-+-+-+-+
    *  |  CMR  |R|R|R|R|
    *  +-+-+-+-+-+-+-+-+
