@@ -27,6 +27,13 @@
 
 #include "gstrtpspeexdepay.h"
 
+/* elementfactory information */
+static const GstElementDetails gst_rtp_speexdepay_details =
+GST_ELEMENT_DETAILS ("RTP Speex depayloader",
+    "Codec/Depayloader/Network",
+    "Extracts Speex audio from RTP packets",
+    "Edgard Lima <edgard.lima@indt.org.br>");
+
 /* RtpSPEEXDepay signals and args */
 enum
 {
@@ -71,14 +78,11 @@ gst_rtp_speex_depay_base_init (gpointer klass)
 {
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_rtp_speex_depay_src_template);
-  gst_element_class_add_static_pad_template (element_class,
-      &gst_rtp_speex_depay_sink_template);
-  gst_element_class_set_details_simple (element_class, "RTP Speex depayloader",
-      "Codec/Depayloader/Network/RTP",
-      "Extracts Speex audio from RTP packets",
-      "Edgard Lima <edgard.lima@indt.org.br>");
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_rtp_speex_depay_src_template));
+  gst_element_class_add_pad_template (element_class,
+      gst_static_pad_template_get (&gst_rtp_speex_depay_sink_template));
+  gst_element_class_set_details (element_class, &gst_rtp_speexdepay_details);
 }
 
 static void
@@ -212,8 +216,7 @@ gst_rtp_speex_depay_process (GstBaseRTPDepayload * depayload, GstBuffer * buf)
   /* nothing special to be done */
   outbuf = gst_rtp_buffer_get_payload_buffer (buf);
 
-  if (outbuf)
-    GST_BUFFER_DURATION (outbuf) = 20 * GST_MSECOND;
+  GST_BUFFER_DURATION (outbuf) = 20 * GST_MSECOND;
 
   return outbuf;
 }
@@ -222,5 +225,5 @@ gboolean
 gst_rtp_speex_depay_plugin_init (GstPlugin * plugin)
 {
   return gst_element_register (plugin, "rtpspeexdepay",
-      GST_RANK_SECONDARY, GST_TYPE_RTP_SPEEX_DEPAY);
+      GST_RANK_MARGINAL, GST_TYPE_RTP_SPEEX_DEPAY);
 }
